==> odps-center-api-1.1.72-20230711.024527-4-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerPageAccessDetailDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * 开发者积分商城页面访问数据接口回传
 */
public class DuibaPartnerPageAccessDetailDTO implements Serializable {

    /**
     * 自增主键
     */
    private Long id;

    /**
     * app_id
     */
    private String appId;

    /**
     * 浏览日期
     */
    private String exposureDt;

    /**
     * 页面id
     */
    private String skinId;

    /**
     * 页面名称
     */
    private String skinName;

    /**
     * 兑吧客户id
     */
    private String consumerId;

    /**
     * 开发者客户id
     */
    private String partnerUserId;

    /**
     * 浏览时间
     */
    private String userExpTime;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 类型
     * 1、商城页面2、活动页面3、商品详情页
     */
    private Integer type;

    /**
     * 浏览唯一标识
     */
    private String browseId;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppId() {
        return appId;
    }

    public void setExposureDt(String exposureDt) {
        this.exposureDt = exposureDt;
    }

    public String getExposureDt() {
        return exposureDt;
    }

    public void setSkinId(String skinId) {
        this.skinId = skinId;
    }

    public String getSkinId() {
        return skinId;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setConsumerId(String consumerId) {
        this.consumerId = consumerId;
    }

    public String getConsumerId() {
        return consumerId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getUserExpTime() {
        return userExpTime;
    }

    public void setUserExpTime(String userExpTime) {
        this.userExpTime = userExpTime;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getBrowseId() {
        return browseId;
    }

    public void setBrowseId(String browseId) {
        this.browseId = browseId;
    }
}

==> odps-center-api-1.2.6-20240102.122148-1-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerPageAccessDetailDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * 开发者积分商城页面访问数据接口回传
 */
public class DuibaPartnerPageAccessDetailDTO implements Serializable {

    /**
     * 自增主键
     */
    private Long id;

    /**
     * app_id
     */
    private String appId;

    /**
     * 浏览日期
     */
    private String exposureDt;

    /**
     * 页面id
     */
    private String skinId;

    /**
     * 页面名称
     */
    private String skinName;

    /**
     * 兑吧客户id
     */
    private String consumerId;

    /**
     * 开发者客户id
     */
    private String partnerUserId;

    /**
     * 浏览时间
     */
    private String userExpTime;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 类型
     * 1、商城页面2、活动页面3、商品详情页
     */
    private Integer type;

    /**
     * 浏览唯一标识
     */
    private String browseId;

    /**
     * 页面类型 (act:活动 skin:组装H5 item:商品)
     */
    private String browsePageType;
    /**
     * 操作平台 (1:ios-app 2:安卓-app 3:小程序 4:微信浏览器 5:浏览器)
     */
    private Integer operatingPlatform;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppId() {
        return appId;
    }

    public void setExposureDt(String exposureDt) {
        this.exposureDt = exposureDt;
    }

    public String getExposureDt() {
        return exposureDt;
    }

    public void setSkinId(String skinId) {
        this.skinId = skinId;
    }

    public String getSkinId() {
        return skinId;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setConsumerId(String consumerId) {
        this.consumerId = consumerId;
    }

    public String getConsumerId() {
        return consumerId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getUserExpTime() {
        return userExpTime;
    }

    public void setUserExpTime(String userExpTime) {
        this.userExpTime = userExpTime;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getBrowseId() {
        return browseId;
    }

    public void setBrowseId(String browseId) {
        this.browseId = browseId;
    }

    public String getBrowsePageType() {
        return browsePageType;
    }

    public void setBrowsePageType(String browsePageType) {
        this.browsePageType = browsePageType;
    }

    public Integer getOperatingPlatform() {
        return operatingPlatform;
    }

    public void setOperatingPlatform(Integer operatingPlatform) {
        this.operatingPlatform = operatingPlatform;
    }
}
